@@ -305,6 +305,8 @@ def _combine_callbacks(callbacks):
             for item in entry:
                 # Check for exact matches.
                 match = item == prop_id
+                if match:
+                    break
                 # Check for wild card matches.
                 if any([wildcard_value in item for wildcard_value in _wildcard_values]):
                     try:
@@ -557,7 +559,7 @@ class NoOutputTransform(DashTransform):
 
     def layout(self, layout, layout_is_function):
         if layout_is_function or not self.initialized:
-            children = layout.children + self.hidden_divs
+            children = _as_list(layout.children) + self.hidden_divs
             layout.children = children
             self.initialized = True
         return layout
